<?php

namespace Drupal\webicons\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\webicons\Services\IconServiceInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\OpenModalDialogCommand;

/**
 * Returns responses for Country Utils routes.
 */
class IconSelectorController extends ControllerBase {

  /** @var \Drupal\webicons\Services\IconServiceInterface  */
  protected $iconService;

  /**
   * Constructs a new IconSelectorController object.
   *
   * @param \Drupal\webicons\Services\IconServiceInterface $iconService
   *   The icon service.
   */
  public function __construct(IconServiceInterface $iconService) {
    $this->iconService = $iconService;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('webicons.service')
    );
  }

  /**
   * Open the icon selector.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The current request.
   *
   * @return \Drupal\Core\Ajax\AjaxResponse
   *   The response.
   */
  public function iconSelectorDialog(Request $request) {
    $libraryId = $request->get('lid');
    $wrapperId = $request->get('wid');
    $iconFactory = $this->iconService->getIconFactory($libraryId);
    $itemsRenderer = $iconFactory->getSelectorIconsRenderTemplate();
    $libraryName = $iconFactory->getLibraryName();
    $build = [
      '#theme' => 'icon_selector',
      '#icons' => $iconFactory->getIcons(),
      '#renderer' => $itemsRenderer,
      '#library' => $libraryName,
      '#attached' => [
        'library' => [
          'webicons/icon-dialog',
          $libraryName
        ],
        'drupalSettings' => [
          'webIconField' => [
            'wrapperId' => $wrapperId,
          ],
        ],
      ],
    ];
    $response = new AjaxResponse();
    $response->addCommand(new OpenModalDialogCommand($this->t('Select an Icon'), $build, ['width' => '800']));
    return $response;
  }
}
