<?php

namespace Drupal\webicons\Plugin\Field\FieldFormatter;

use Drupal\webicons\Services\IconServiceInterface;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the 'webicons_field_default' formatter.
 *
 * @FieldFormatter(
 *   id = "webicons_field_default",
 *   label = @Translation("Default"),
 *   field_types = {"webicons_field"}
 * )
 */
class WebIconsFieldDefaultFormatter extends FormatterBase {

  /**
   * The Icon Service.
   *
   * @var \Drupal\webicons\Services\IconServiceInterface
   */
  private IconServiceInterface $iconService;

  /**
   * Constructs a new default formatter instance.
   *
   * @param $plugin_id
   *   The plugin_id for the plugin instance.
   * @param $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Field\FieldDefinitionInterface $field_definition
   *   The field definition.
   * @param array $settings
   *   The settings array.
   * @param $label
   *   The formatter label.
   * @param $view_mode
   *   The formatter view mode.
   * @param array $third_party_settings
   *   The third party settings array.
   * @param \Drupal\webicons\Services\IconServiceInterface $iconService
   *   The icon service.
   */
  public function __construct($plugin_id, $plugin_definition, FieldDefinitionInterface $field_definition, array $settings, $label, $view_mode, array $third_party_settings, IconServiceInterface $iconService) {
    parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $label, $view_mode, $third_party_settings);
    $this->iconService = $iconService;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $plugin_id,
      $plugin_definition,
      $configuration['field_definition'],
      $configuration['settings'],
      $configuration['label'],
      $configuration['view_mode'],
      $configuration['third_party_settings'],
      $container->get('webicons.service')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $libraryId = $items->getFieldDefinition()->getSetting('icon_library');
    $iconFactory = $this->iconService->getIconFactory($libraryId);
    $element = [];
    foreach ($items as $delta => $item) {
      $iconRender = $iconFactory->getIconRenderArray($items[$delta]->getValue());
      $element[$delta] = $iconRender;
    }
    return $element;
  }
}
