<?php

namespace Drupal\webicons\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\TypedData\DataDefinition;
use Drupal\webicons\Services\IconServiceInterface;

/**
 * Defines the 'webicons_field' field type.
 *
 * @FieldType(
 *   id = "webicons_field",
 *   label = @Translation("Webicons Field"),
 *   category = @Translation("Webicons"),
 *   default_widget = "webicons_field",
 *   default_formatter = "webicons_field_default",
 * )
 * cardinality = \Drupal\Core\Field\FieldStorageDefinitionInterface::CARDINALITY_UNLIMITED,
 * cardinality = 1,
 */
class WebIconsFieldItem extends FieldItemBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultFieldSettings() {
    return [
      'icon_library' => 'boxicons',
    ] + parent::defaultFieldSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function fieldSettingsForm(array $form, FormStateInterface $form_state) {
    $settings = $this->getSettings();
    $element['icon_library'] = [
      '#type' => 'select',
      '#title' => $this->t('Select icon library'),
      '#options' => IconServiceInterface::ICONS,
      '#default_value' => $settings['icon_library'],
    ];
    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    if ($this->icon_class !== NULL) {
      return FALSE;
    }
    elseif ($this->icon_code !== NULL) {
      return FALSE;
    }
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    $properties['icon_class'] = DataDefinition::create('string')
      ->setLabel(t('Icon class'));
    $properties['icon_code'] = DataDefinition::create('string')
      ->setLabel(t('Icon code'));
    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    $columns = [
      'icon_class' => [
        'type' => 'varchar',
        'length' => 255,
      ],
      'icon_code' => [
        'type' => 'varchar',
        'length' => 255,
      ],
    ];
    $schema = [
      'columns' => $columns,
    ];
    return $schema;
  }

  /**
   * Create custom constraints.
   *
   * Example of custom constraints:
   * $options['method']['AllowedValues'] = array_keys(RedsysItem::allowedMethodValues());
   * $options['method']['NotBlank'] = [];
   * $constraint_manager = \Drupal::typedDataManager()->getValidationConstraintManager();
   * $constraints[] = $constraint_manager->create('ComplexData', $options);
   * return $constraints;
   *
   * {@inheritdoc}
   */
  public function getConstraints() {
    $constraints = parent::getConstraints();
    return $constraints;
  }
}
