<?php

namespace Drupal\webicons\Services;

interface IconFactoryInterface {

  /**
   * Return the library id.
   *
   * @return string
   *  The library id.
   */
  public function getLibraryId(): string;

  /**
   * Return the library name.
   *
   * This is used to store the library name in .libraries file.
   * You can overwrite this function to implement new library factories
   * outside this module.
   *
   * @return string
   *  The library name.
   */
  public function getLibraryName(): string;

  /**
   * Get the cache id for the library.
   *
   * @return string
   *  The cache id.
   */
  public function getLibraryCacheId(): string;

  /**
   * Get the template for render the icons in the selector.
   *
   * @return string
   *  The twig template.
   */
  public function getSelectorIconsRenderTemplate(): string;

  /**
   * Get the icon render array.
   *
   * @param array $keyValues
   *  Key/values to be passed to template.
   * @param array $classes
   *  Classes for the icon.
   *
   * @return array
   *  Icon render array.
   */
  public function getIconRenderArray(array $keyValues, array $classes=[]): array;

  /**
   * Get the icons from the cache if exists or from the library.
   *
   * @return array
   *  The icons.
   */
  public function getIcons(): array;

  /**
   * This function should be implemented by child factory.
   *
   * As each icon library have its own css icons, it is necessary that each
   * icon factory implement its own method to extract the icons.
   *
   * @return array
   *  The extracted icons.
   */
  public function extractFromLibrary(): array;

  /**
   * Store the icons into the default cache.
   *
   * @param array $icons
   *  The icons.
   *
   * @return array
   *  The same icons passed to the function.
   */
  public function saveIconsIntoCache(array $icons): array;
}
