<?php

namespace Drupal\webicons\Services;

/**
 * Icon Service Interface.
 */
interface IconServiceInterface {

  public const ICONS = [
    'boxicons' => 'Box Icons',
    'fortawesome' => 'Fortawesome Icons',
    'materialicons' => 'Material Icons',
  ];

  /**
   * Get service name prefix.
   *
   * By default, this function should return a value like 'webicons.', that
   * indicates that invoked services are from this module.
   *
   * This function exits to allow to override the icon service to provide
   * custom service/factory icons.
   *
   * @return string
   *  The service prefix.
   */
  public function getServicePrefix(): string;

  /**
   * Get the appropriated Icon Factory based on library id.
   *
   * @param string $libraryId
   *  The library id.
   *
   * @return \Drupal\webicons\Services\IconFactoryInterface
   *  Icon Factory implementation.
   */
  public function getIconFactory(string $libraryId): IconFactoryInterface;

}
