<?php

namespace Drupal\webicons;

use Drupal\webicons\Services\IconServiceInterface;
use Twig\Extension\AbstractExtension;
use Twig\TwigFunction;

/**
 * Twig extension.
 */
final class WebiconsTwigExtension extends AbstractExtension {

  /**
   * @var \Drupal\webicons\Services\IconServiceInterface
   */
  protected IconServiceInterface $iconService;

  /**
   * Constructs the extension object.
   *
   * @param \Drupal\webicons\Services\IconServiceInterface $iconService
   */
  public function __construct(IconServiceInterface $iconService) {
    $this->iconService = $iconService;
  }

  /**
   * {@inheritdoc}
   */
  public function getFunctions(): array {
    return [
      new TwigFunction('webicon', [$this, 'getWebicon'])
    ];
  }

  /**
   * Get icon render.
   *
   * @param string $libraryId
   *  Library ID.
   * @param array $keyValues
   *  Key values (icon_class, icon_code, etc.).
   * @param array $classes
   *  List of classes to append to the icon.
   *
   * @return array
   *  Icon rendered.
   */
  public function getWebicon(string $libraryId, array $keyValues, array $classes=[]): array {
    return $this->iconService->getIconFactory($libraryId)->getIconRenderArray($keyValues, $classes);
  }

}
